@@ -25,10 +25,10 @@
 #include <errno.h>
 #include <sys/types.h>
 #include <dirent.h>
+#include <stdlib.h>
 
 #include "menu-util.h"
 #include "menu-monitor.h"
-#include "canonicalize.h"
 
 typedef struct CachedDir CachedDir;
 typedef struct CachedDirMonitor CachedDirMonitor;
@@ -731,7 +731,7 @@ static EntryDirectory* entry_directory_new_full(DesktopEntryType entry_type, con
                 path,
                 is_legacy ? "<yes>" : "<no>");
 
-  canonical = menu_canonicalize_file_name (path, FALSE);
+  canonical = realpath (path, NULL);
   if (canonical == NULL)
     {
       menu_verbose ("Failed to canonicalize \"%s\": %s\n",
