@@ -23,9 +23,7 @@
 #include <glib.h>
 #include "desktop-entries.h"
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+G_BEGIN_DECLS
 
 typedef struct EntryDirectory EntryDirectory;
 
@@ -60,8 +58,6 @@ DesktopEntry* entry_directory_list_get_directory (EntryDirectoryList* list, cons
 DesktopEntrySet* _entry_directory_list_get_all_desktops(EntryDirectoryList* list);
 void _entry_directory_list_empty_desktop_cache(void);
 
-#ifdef __cplusplus
-}
-#endif
+G_END_DECLS
 
 #endif /* __ENTRY_DIRECTORIES_H__ */
